%define name	sympa
%define version 6.1.17
%define release %mkrel 3
%define subrel 3

%define _provides_exceptions perl(.*)
%define _requires_exceptions perl(\\(Sympa.*\\|Archive\\|Auth\\|Bounce\\|Bulk\\|Commands\\|Conf\\|Config_XML\\|Datasource\\|Family\\|Fetch\\|Language\\|Ldap\\|List\\|Lock\\|Log\\|Marc.*\\|Message\\|PlainDigest\\|Robot\\|SharedDocument\\|Scenario\\|SQLSource\\|Task\\|Upgrade\\|WebAgent\\))

Name:		%{name}
Version:	%{version}
Release:	%{release}
Summary:	Electronic mailing list manager
License:	GPL
Group:		System/Servers
URL:		http://www.sympa.org/
Source0:	http://www.sympa.org/distribution/%{name}-%{version}.tar.gz
Source1:	sympa.service
Source2:	sympa-bulk.service
Source3:	sympa-archived.service
Source4:	sympa-bounced.service
Source5:	sympa-task_manager.service
Source6:	sympa.tmpfiles
Patch0:		sympa-6.1.17-pod-encoding.patch
Patch1:		sympa-CVE-2015-1306.patch
Requires:	openssl >= 0.9.5a
Requires:	mhonarc >= 2.4.5
Requires:       mail-server
Requires(pre):	    rpm-helper
Requires(post):     rpm-helper >= 0.20.0
Requires(post):     mail-server
Requires(preun):    rpm-helper
Requires(preun):    mail-server
Requires(postun):   rpm-helper >= 0.16
BuildRequires:      rpm-helper >= 0.20.0
BuildRequires:      rpm-mageia-setup
BuildRequires:	    openssl-devel
BuildRequires:	    perl-MailTools
BuildRequires:	    perl-libintl-perl
BuildRequires:	    gettext-devel
BuildRequires:	    perl(HTML::StripScripts::Parser)

%description
SYMPA is an electronic mailing list manager. It is used to automate list
management functions such as subscription, moderation and management of 
archives. SYMPA also manages sending of messages to the lists, and 
makes it possible to reduce the load on the system. Provided that you 
have enough memory on your system, Sympa is especially well adapted for big 
lists. For a list with 20 000 subscribers, it takes 5 minutes to send a
message to 90% of subscribers, of course considering that the network is 
available.

Documentation is available under HTML and SGML (source) formats. 

%package www
Summary:	Web interface for %{name}
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	webserver
Suggests:   apache-mod_fastcgi
Suggests:   perl(CGI::Fast)
Suggests:   perl(FCGI)
Requires(post):     rpm-helper >= 0.20.0
Requires(postun):   rpm-helper >= 0.16

%description www
This package contains the web interface for %{name}.

%prep
%setup -q 
%patch0 -p1
%patch1 -p2

%build
%serverbuild
%configure2_5x \
    --enable-fhs \
    --libexecdir=%{_sbindir} \
    --sysconfdir=%{_sysconfdir}/sympa \
    --with-confdir=%{_sysconfdir}/sympa \
    --with-sendmail_aliases=%{_localstatedir}/lib/sympa/aliases \
    --with-newaliases_arg=-oA/var/lib/sympa/aliases
%make

%install
rm -rf %{buildroot}
%makeinstall_std HOST=localhost

perl -pi -e 's|/var/run|/run|' \
    %{buildroot}%{_sysconfdir}/sympa/sympa.conf \
    %{buildroot}%{_sysconfdir}/sympa/wwsympa.conf

rm -f %{buildroot}%{_sysconfdir}/sympa/rc.d/init.d/sympa
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/sympa.service
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/sympa-bulk.service
install -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/sympa-archived.service
install -D -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/sympa-bounced.service
install -D -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/sympa-task_manager.service
install -D -m 644 %{SOURCE6} %{buildroot}%{_prefix}/lib/tmpfiles.d/sympa.conf

# apache conf
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/sympa.conf <<EOF
Alias /static-sympa %{_localstatedir}/lib/sympa/static_content
Alias /sympa %{_libdir}/sympa/cgi

<Directory %{_localstatedir}/lib/sympa/static_content>
    Require all granted
</Directory>

<Directory %{_libdir}/sympa/cgi>
    Options ExecCGI
    # fallback handler if mod_fcgid is not installed
    <IfModule !mod_fcgid.c>
        AddHandler cgi-script .fcgi
    </IfModule>
    DirectoryIndex wwsympa-wrapper.fcgi
    Require all granted
</Directory>
EOF

cat > README.urpmi <<EOF
Mageia RPM specific notes
-------------------------

Setup
-----
The setup used here differs from default one, to achieve better FHS compliance.
- the binaries are in %{_bindir} and %{_sbindir}
- the configuration files are in %{_sysconfdir}/sympa
- the constant files are in %{_libdir}/sympa and %{_datadir}/sympa
- the variable files are in %{_localstatedir}/lib/sympa
- the logs files are in %{_localstatedir}/log/sympa

Post-installation
-----------------
Sympa requires a database for using the web interface. You have to create it
using the adequate script among %{_datadir}/sympa/bin. You also need to install
the proper DBI driver package for your database.

You can regenerate configuration files for sympa by executing
%{_sbindir}/sympa_wizard.pl

Additional useful packages
--------------------------
- perl-ldap for LDAP support
- perl-DBD-mysql for mysql support
- perl-DBD-pg for postgresql support
- apache-mod-fcgid for fast-CGI support
EOF

# Install remaining documentation manually
install -m 644 COPYING README NEWS README.urpmi %{buildroot}%{_docdir}/%{name}

# don't install  bundled certs
rm -f %{buildroot}%{_datadir}/sympa/ca-bundle.crt

%find_lang sympa
%find_lang web_help
cat web_help.lang >> sympa.lang

%pre
%_pre_useradd sympa %{_localstatedir}/lib/sympa /bin/false

%post
%_post_service sympa

if [ $1 = 1 ]; then
  # installation

  # sympa configuration
  hostname=`hostname`

  perl -pi \
    -e "s|^domain(\s+).*|domain\$1$hostname|;" \
    -e "s|^listmaster(\s+).*|listmaster\$1listmaster\@$hostname|;" \
    -e "s|^wwsympa_url(\s+).*|wwsympa_url\$1http://$hostname/sympa|;" \
    -e "s|^syslog(\s+).*|syslog\$1mail|;" \
    %{_sysconfdir}/sympa/sympa.conf

  # Initial aliase file creation
  cat >> %{_localstatedir}/lib/sympa/aliases <<EOF
listmaster:	"|%{_sbindir}/queue listmaster"
sympa:		"|%{_sbindir}/queue sympa"
bounce+*:	"|%{_sbindir}/bouncequeue sympa"
sympa-request:	listmaster@$hostname
sympa-owner:	listmaster@$hostname
EOF
  chown sympa.sympa %{_localstatedir}/lib/sympa/aliases

  # mta-specific aliases inclusion procedure
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database`
    maps=`/usr/sbin/postconf -h alias_maps`
    postconf -e \
        "alias_database = $database, hash:%{_localstatedir}/lib/sympa/aliases" \
        "alias_maps = $maps, hash:%{_localstatedir}/lib/sympa/aliases"
  else
    cat >> %{_sysconfdir}/aliases <<EOF
:include:	%{_localstatedir}/lib/sympa/aliases
EOF
  fi
  # masqmail don't have this command
  [ -x /usr/bin/newaliases ] && /usr/bin/newaliases
else
  # find aliases file
  aliases=`awk '/sendmail_aliases/ {print $2}' %{_sysconfdir}/sympa/sympa.conf`
  if [ -z "$aliases" ]; then
    aliases=%{_sysconfdir}/aliases
  fi
  # correct pathes
  sed -i \
      -e 's|%{_bindir}/queue|%{_sbindir}/queue|' \
      -e 's|%{_bindir}/bouncequeue|%{_sbindir}/bouncequeue|' \
      $aliases
  # regenerate aliases
  /usr/bin/newaliases
fi

%preun
%_preun_service sympa

if [ $1 = 0 ]; then
  # uninstallation

  # remove aliases
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    maps=`/usr/sbin/postconf -h alias_maps | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    postconf -e \
      "alias_database = $database" \
      "alias_maps = $maps"
  else
    sed -i -e '/:include:   %{_localstatedir}/lib/sympa/aliases/d' \
      %{_sysconfdir}/aliases
  fi
  /usr/bin/newaliases
fi

%postun
%_postun_userdel sympa

%files -f sympa.lang
%{_docdir}/%{name}

# variable directories
%attr(-,sympa,sympa) %{_localstatedir}/lib/sympa
%attr(-,sympa,sympa) %{_localstatedir}/spool/sympa

# config files
%dir %{_sysconfdir}/sympa
%config(noreplace) %attr(640,root,sympa) %{_sysconfdir}/sympa/sympa.conf
%config(noreplace) %{_sysconfdir}/sympa/wwsympa.conf
%config(noreplace) %{_sysconfdir}/sympa/data_structure.version

%{_unitdir}/sympa.service
%{_unitdir}/sympa-bulk.service
%{_unitdir}/sympa-archived.service
%{_unitdir}/sympa-bounced.service
%{_unitdir}/sympa-task_manager.service
%{_prefix}/lib/tmpfiles.d/sympa.conf

# binaries
%attr(-,sympa,sympa) %{_sbindir}/queue
%attr(-,sympa,sympa) %{_sbindir}/bouncequeue
%attr(-,sympa,sympa) %{_sbindir}/familyqueue
%attr(-,root,sympa) %{_sbindir}/aliaswrapper
%attr(-,root,sympa) %{_sbindir}/virtualwrapper
%{_sbindir}/sympa.pl
%{_sbindir}/alias_manager.pl
%{_sbindir}/archived.pl
%{_sbindir}/bounced.pl
%{_sbindir}/bulk.pl
%{_sbindir}/sympa_wizard.pl
%{_sbindir}/task_manager.pl

# other
%{_datadir}/sympa
%{_mandir}/man8/*

%files www
%dir %{_libdir}/sympa
%dir %{_libdir}/sympa/cgi
%{_libdir}/sympa/cgi/wwsympa.fcgi
%{_libdir}/sympa/cgi/sympa_soap_server.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/sympa_soap_server-wrapper.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/wwsympa-wrapper.fcgi
%config(noreplace) %{_webappconfdir}/sympa.conf


%changelog
* Tue Feb 17 2015 guillomovitch <guillomovitch> 6.1.17-3.3.mga4
+ Revision: 815408
- add a soft dependency on FCGI perl module (#15097)
- only provide a fallback handler for wwsympa.fcgi if mod_fcgid is not installed, in default apache configuration
- add upstream patch to fix CVE-2015-1306

* Mon Oct 21 2013 luigiwalser <luigiwalser> 6.1.17-3.mga4
+ Revision: 540836
- fix pod2man errors due to non-ascii chars with no encoding set

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

  + guillomovitch <guillomovitch>
    - define newaliases arg at build time, to ensure correct alias update

* Wed Feb 06 2013 guillomovitch <guillomovitch> 6.1.17-1.mga3
+ Revision: 394785
- new version

* Mon Jan 14 2013 umeabot <umeabot> 6.1.16-2.mga3
+ Revision: 383886
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 17 2012 guillomovitch <guillomovitch> 6.1.16-1.mga3
+ Revision: 319138
- new version

* Sat Oct 06 2012 guillomovitch <guillomovitch> 6.1.15-1.mga3
+ Revision: 303060
- new version

* Fri Sep 14 2012 guillomovitch <guillomovitch> 6.1.14-1.mga3
+ Revision: 293844
- new version

* Fri Aug 24 2012 guillomovitch <guillomovitch> 6.1.11-5.mga3
+ Revision: 283663
- make webapp configuration file compliant with apache 2.4

* Sat Aug 04 2012 guillomovitch <guillomovitch> 6.1.11-4.mga3
+ Revision: 278467
- fix path in apache configuration file (#6772)

* Tue Jul 10 2012 guillomovitch <guillomovitch> 6.1.11-2.mga3
+ Revision: 269257
- add systemd support
- drop sysinit support
- add soft dependency on perl-CGI-Fast
- update README.urpmi, as db schema files location changed
- mention the need of proper DBD driver package
- new version

* Tue May 08 2012 pterjan <pterjan> 6.1.9-2.mga2
+ Revision: 234918
- Fix initscript's LSB header

* Tue Mar 27 2012 guillomovitch <guillomovitch> 6.1.9-1.mga2
+ Revision: 227182
- new version

* Wed Dec 07 2011 guillomovitch <guillomovitch> 6.1.7-1.mga2
+ Revision: 178321
- new version

* Mon Sep 26 2011 dmorgan <dmorgan> 6.1.5-2.mga2
+ Revision: 147873
- Fix deps in rpm-mageia-setup

* Sun Jun 19 2011 kharec <kharec> 6.1.5-1.mga2
+ Revision: 109677
- new version 6.1.5

* Sun May 15 2011 pterjan <pterjan> 6.1.4-2.mga1
+ Revision: 98970
- Rebuild for fixed find-requires

* Mon Apr 18 2011 misc <misc> 6.1.4-1.mga1
+ Revision: 87648
- remove version check, as all recents versions are ok
- update sympa to 6.1.4

* Sun Mar 06 2011 ennael <ennael> 6.1.3-1.mga1
+ Revision: 65703
- clean spec file

  + kharec <kharec>
    - imported package sympa

